#! perl -w

use strict;
use warnings;
use Cwd;
my $home = cwd();

my $targetDirectory = 'V:\\Supplements\\ReproRsch-Ovary';
die "Target directory ($targetDirectory) does not exist.\n" unless (-d $targetDirectory);

# INDEX is the main web page for the supporting material
open(INDEX, ">$targetDirectory/index.html") or die "Cannot create index.html\n";

# print the header
my $title = 'Run Batch Effects and Ovarian Cancer';
my $msTitle = 'Run batch effects potentially compromise the usefulness '
    .'of genomic signatures for ovarian cancer';
print INDEX <<EOF;
<HTML><HEAD><TITLE>$title</TITLE></HEAD>
<BODY>
<H1>$title</H1>
<P>This web page contains supporting material for the manuscript
<I>$msTitle</I>, 
by Keith A. Baggerly, Shannon Neeley, and Kevin R. Coombes.</P>  
<P>Here is a list of the available material.  The main manuscript and 
supplementary reports are in PDF format.  The source code, intermediate results,
and public data sources are in zip files, starting from a common directory.
<P><UL>
EOF

#doCopy('SR0.pdf', 'Main Supplement (SR0)', 'Unable to copy main file');

# source code
my @ms = glob "*";
chdir "RNowebSource";
my @rnw = glob "*";
chdir $home;
my @list = ('zip', 'sourceCode');
foreach my $ms (@ms) {
    push @list, "JCO-OvCa/$ms";
}
foreach my $rnw (@rnw) {
    push @list, "JCO-OvCa/RNowebSource/$rnw";
}
chdir "..";
system(@list) == 0 or die "Cannot create zip file of source code\n";
doCopy("sourceCode.zip", "Source Code");
unlink "sourceCode.zip";
chdir $home;

# supplementary PDFs
print INDEX "<LI>Supplementary reports:\n<UL>\n";
foreach my $i (1..7) {
    my $source = "LaTex\\ovca0$i.pdf";
    doCopy($source, "Supplementary Report ovca0$i");
}
print INDEX "</UL>\n";

# intermediate results
my @otherDirs = qw/Figures LaTeX RDataObjects Tangled/;

chdir "..";
print INDEX "<LI>Intermediate results:\n<UL>\n";
foreach my $dir (@otherDirs) {
    my @args = ('zip', '-r', $dir, "JCO-OvCa/$dir");
    system(@args) == 0 or die "Cannot zip $dir\n";
    doCopy("$dir.zip", $dir);
    unlink "$dir.zip";
}
print INDEX "</UL>\n";
chdir $home;

#public data sources
chdir "./OtherData";
my @pds = glob "*";
chdir "..";
print INDEX "<LI>Public data sources:\n<UL>\n";
foreach my $pubdir (@pds) {
    next unless (-d "OtherData/$pubdir");
    my @args = ('zip', '-r', $pubdir, "OtherData/$pubdir");
    print join(' ', @args), "\n";
    system(@args) == 0 or die "Cannot execute ",  join(' ', @args), "\n";
    doCopy("$pubdir.zip", $pubdir);
    unlink "$pubdir.zip";
}

#Duke web site
chdir "../DukeWebSite";
my @pds = glob "*";
chdir "..";
#print INDEX "<LI>Public data sources:\n<UL>\n";
foreach my $pubdir (@pds) {
    next unless (-d "DukeWebSite/$pubdir");
    my @args = ('zip', '-r', $pubdir, "DukeWebSite/$pubdir");
    print join(' ', @args), "\n";
    system(@args) == 0 or die "Cannot execute ",  join(' ', @args), "\n";
    doCopy("$pubdir.zip", $pubdir);
    unlink "$pubdir.zip";
}
chdir $home;
print INDEX "</UL>\n";

# finish the INDEX file
my $now = gmtime;
print INDEX <<EOF;
</UL>
<P>
Our analysis source code relies on a number of software programs and auxiliary packages; 
we provide scripts, not stand-alone executables.  Detailed descriptions of the
packages (with version numbers) are listed in the methods section of the main 
manuscript. The pieces of software required to execute the source code can be
obtained from the following locations:
<UL>
<LI>The main program and several package libraries from the 
<A HREF="http://cran.r-project.org"> R environment for statistical programming</A>.
<LI>Several package libraries from <A HREF="http://bioconductor.org">BioConductor</A>.
<LI>Several package libraries from <A HREF="http://bioinformatics.mdanderson.org/Software/OOMPA">OOMPA</A>.
<LI>A working version of <A HREF="http://www.ctan.org">LaTeX</A>, the text formatting
system based on the work of Donald Knuth.
<LI>The commercial softare program <A HREF="http://www.mathworks.com">MATLAB</A>
</UL>
</P>
<HR>
<P>
This page was produced on: $now GMT. Our intention is to avoid changing 
the files posted here, allowing the web site to serve as permanent 
documentation of our analysis.  Any changes will be posted on a separate 
page designed for <A HREF='./Modified/index.html'>addenda, errata, corrigenda</A> 
and other related latinisms.
</P>
EOF

print INDEX "\n</BODY></HTML>\n";
close(INDEX) or die "Cannot finalize index.html\n";

exit;

sub doCopy {
    my $filepath = shift; 
    my $label = shift;
    my $warn = shift || 'system call failed';
    my $file = $filepath;
    if ($file =~ /\\(.*)/) {
	$file = $1;
    }
    my @args = ('copy', $filepath, $targetDirectory);
    system(@args) == 0 or die "$warn\n";
    my @stats = stat $filepath;
    my $size = int($stats[7]/1024);
    
    print INDEX "<LI><A HREF='$file'>$label ($size KB)</A>\n";
}


